.onAttach <- function(libname = find.package("furniture"), pkgname = "furniture") {
  packageStartupMessage("furniture 1.6.0: learn more at tysonbarrett.com")
}